#
# spec file for package python-parallax
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-parallax
Version:        1.0.8
Release:        3.3
Summary:        Python module for multi-node SSH command execution and file copy
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/krig/parallax/
Source:         https://files.pythonhosted.org/packages/source/p/parallax/parallax-%{version}.tar.gz
Patch1:         0001-Fix-manager-writer-thread-can-only-be-started-once-b.patch

BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%define oldpython python
Obsoletes:      %{oldpython}-parallax < %{version}
Requires:       openssh
BuildArch:      noarch
%if 0%{?suse_version}
Requires(post): update-alternatives
Requires(postun): update-alternatives
%else
Requires(post): %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives
%endif
%python_subpackages

%description
Parallax SSH provides an interface to executing commands on multiple
nodes at once using SSH. It also provides commands for sending and receiving files to
multiple nodes using SCP.

%prep
%autosetup -p1 -n parallax-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/parallax-askpass

%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative parallax-askpass

%postun
%python_uninstall_alternative parallax-askpass

%files %{python_files}
%doc AUTHORS README.md
%license COPYING
%{python_sitelib}/parallax
%{python_sitelib}/parallax-%{version}*.egg-info
%python_alternative %{_bindir}/parallax-askpass

%changelog
* Thu May 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Fri Mar  3 2023 XinLiang <XLiang@suse.com>
- Fix: manager: writer thread can only be started once (bsc#1208817)
  Add patch 0001-Fix-manager-writer-thread-can-only-be-started-once-b.patch
* Mon Nov  7 2022 XinLiang <XLiang@suse.com>
- Fix: manager: file descriptor leakage
- Release 1.0.8
* Thu Nov  3 2022 XinLiang <XLiang@suse.com>
- Release 1.0.7
- Remove patches since already included:
  Remove patch 0001-Add-ssh_key-option-used-by-i-option-of-ssh-scp.patch
  Remove patch 0002-Change-format-of-scp-command-for-ipv6-compatible.patch
  Remove patch 0003-Fix-task-Don-t-use-ssh-if-command-running-on-local-b.patch
  Remove patch 0004-Fix-Error-inherit-from-Exception-instead-of-BaseExce.patch
  Remove patch 0005-Dev-add-parallax.run-to-return-non-zero-rc-without-r.patch
* Wed Sep 28 2022 Nicholas Yang <nicholas.yang@suse.com>
- Dev: add parallax.run() to return non-zero rc without raising exceptions
  Add patch 0005-Dev-add-parallax.run-to-return-non-zero-rc-without-r.patch
- Fix: Error: inherit from Exception instead of BaseExceptin
  Add patch 0004-Fix-Error-inherit-from-Exception-instead-of-BaseExce.patch
* Thu Jul 28 2022 XinLiang <XLiang@suse.com>
- Don't use ssh if command running on local (bsc#1200833)
  Add patch 0003-Fix-task-Don-t-use-ssh-if-command-running-on-local-b.patch
* Wed Aug  5 2020 XinLiang <XLiang@suse.com>
- Change format of scp command for ipv6 compatible(bsc#1174894)
  Add patch 0002-Change-format-of-scp-command-for-ipv6-compatible.patch
* Tue May 19 2020 XinLiang <XLiang@suse.com>
- Add ssh_key option used by -i option of ssh and scp(bsc#1169581)
  Add patch 0001-Add-ssh_key-option-used-by-i-option-of-ssh-scp.patch
* Wed Apr  1 2020 Kristoffer Gronlund <kgronlund@suse.com>
- Release 1.0.6
- Replace preexec_fn as start_new_session
- No need to mask signals for subprocess call
* Thu Aug 22 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Release 1.0.5
- Surpress warning messages when needed (bsc#1146748)
- Fix assert_ DeprecationWarning
* Tue May 28 2019 Kristoffer Gronlund <kgronlund@suse.com>
- Work around hidden python packaging magic (bsc#1131136)
* Tue Dec 18 2018 kgronlund@suse.com
- Obsolete old python-parallax package (bsc#1103832)
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix Source URL
- Fix fdupes call
* Fri Jul 27 2018 jengelh@inai.de
- Use noun phrase in summary.
* Thu Jun 28 2018 kgronlund@suse.com
- Release 1.0.4
- Fix super call for python2 (bsc#1099514)
* Fri Nov  3 2017 kgronlund@suse.com
- Release 1.0.3
- Add to_ascii function to convert byte message to str (bsc#1066330)
* Mon Aug 28 2017 kgronlund@suse.com
- Release 1.0.2
- Switch to new singlespec packaging
* Thu Dec  8 2016 kgronlund@suse.com
- Fix broken build for non-SUSE distributions (again)
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Apr 27 2016 kgronlund@suse.com
- Fix broken package build for non-SUSE distributions
* Mon Mar  7 2016 kgronlund@suse.com
- Add alternatives entry for parallax-askpass
* Fri Jun 12 2015 kgronlund@suse.com
- Release 1.0.1
  + The host list expander function was not unicode-safe (bsc#934594)
  + Clean up and update documentation for Options.inline (#1)
  + Fix python3 error using askpass option (krig/parallel-ssh#1)
* Thu Feb 12 2015 kgronlund@suse.com
- Release 1.0.0a3
  - Be more accepting with format of limit argument
  - Fix incorrect name of options attribute
* Sat Jan  3 2015 p.drouand@gmail.com
- Fix license to be SPDX compliant; applied license is BSD3 derived
* Thu Dec 25 2014 kgronlund@suse.com
- Release 1.0.0a2
  - Prepend hostname on each line when -P is set (fate#318220)
  - Fix quiet option after API patch
* Thu Nov 20 2014 kgronlund@suse.com
- Revised packaging
- Removed dependency on xz
* Wed Oct 15 2014 kgronlund@suse.com
- Initial release.
